@@ -9,7 +9,7 @@ http://www.logilab.fr/ -- mailto:contact@logilab.fr
 modname = 'forge'
 distname = 'cubicweb-forge'
 
-numversion = (1, 0, 0)
+numversion = (1, 2, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -17,13 +17,24 @@ license = 'LGPL'
 author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 
-short_desc = 'CubicWeb Forge component for collaboratively developing software projects'
-long_desc = '''CubicWeb Forge component for collaboratively developing software projects'''
+short_desc = 'forge component for the CubicWeb framework'
+long_desc = '''This CubicWeb component provides a Forge application
+that supports the process of collaborative developing software.
+
+CubicWeb is a semantic web framework, see http://www.cubicweb.org
+'''
 
 from os import listdir as _listdir
 from os.path import join, isdir
 
 web = 'http://www.cubicweb.org/project/%s' % distname
+classifiers = [
+          'Environment :: Web Environment',
+          'Framework :: CubicWeb',
+          'Programming Language :: Python',
+          'Programming Language :: JavaScript',
+          'Topic :: Software Development :: Bug Tracking',
+          ]
 
 pyversions = ['2.4']
 
@@ -54,7 +65,21 @@ except OSError:
     pass
 
 
-cube_eid = None # <=== FIXME if you need direct bug-subscription
-__use__ = ('file', 'card', 'comment', 'email', 'mailinglist',
-            'tag', 'folder', )
+__depends_cubes__ = {'card': None,
+                     'comment': '>= 1.2.0',
+                     'email': '>= 1.2.1',
+                     'file': '>= 1.2.0',
+                     'folder': '>= 1.1.0',
+                     'mailinglist': '>= 1.1.0',
+                     'tag': '>= 1.2.0',
+                     'tracker': '>= 1.1.0',
+                     'nosylist': None,
+                     }
+__depends__ = {'cubicweb': '>= 3.5.0',
+               }
+for key,value in __depends_cubes__.items():
+    __depends__['cubicweb-'+key] = value
+__use__ = tuple(__depends_cubes__)
+
+
 
