@@ -5,24 +5,12 @@
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
+_ = unicode
 
 from cubicweb.web import uicfg
 from cubicweb.web.views.urlrewrite import (
     SimpleReqRewriter, SchemaBasedRewriter, rgx, build_rset)
 
-class ForgeSimpleReqRewriter(SimpleReqRewriter):
-    """handle path with the form::
-
-    versions -> view versions in state ready or development, or marked as
-                prioritary.
-
-    foaf.rdf -> view the foaf file for all users
-    """
-    rules = [
-        (rgx('/versions'), dict(vid='versionsinfo')),
-        ('/foaf.rdf', dict(vid='foaf', rql='Any X WHERE X is CWUser'))
-        ]
-
 class ForgeURLRewriter(SchemaBasedRewriter):
     """handle path with the form::
 
@@ -37,6 +25,7 @@ class ForgeURLRewriter(SchemaBasedRewriter):
         project/<name>/[version]/tests   -> test for this version
         project/<name>/[version]/tickets -> tickets for this version
     """
+    priority = 10
     rules = [
         (rgx('/project/([^/]+)/testcases'),
          build_rset(rql='Project P WHERE P name %(project)s',
@@ -71,13 +60,22 @@ class ForgeURLRewriter(SchemaBasedRewriter):
         (rgx('/project/([^/]+)/([^/]+)'),
          build_rset(rql='Version X WHERE X version_of P, P name %(project)s, X num %(num)s',
                     rgxgroups=[('project', 1), ('num', 2)])),
+        (rgx('/p/([^/]+)'),
+         build_rset(rql='Project P WHERE P name %(project)s',
+                    rgxgroups=[('project', 1),])),
+        (rgx('/t/([^/]+)'),
+         build_rset(rql='Ticket T WHERE T eid %(teid)s',
+                    rgxgroups=[('teid', 1),])),
          ]
 
-
+# XXX some of those tags should be in tracker cube
 _afs = uicfg.autoform_section
 _afs.tag_attribute(('Version', 'publication_date'), 'generated')
 _afs.tag_attribute(('Version', 'starting_date'), 'primary')
 _afs.tag_attribute(('Version', 'prevision_date'), 'primary')
+_afs.tag_attribute(('Version', 'progress_target'), 'generated')
+_afs.tag_attribute(('Version', 'progress_todo'), 'generated')
+_afs.tag_attribute(('Version', 'progress_done'), 'generated')
 _afs.tag_subject_of(('Version', 'version_of', '*'), 'secondary')
 _afs.tag_object_of(('TestInstance', 'for_version', 'Version'), 'generated')
 _afs.tag_attribute(('Ticket', 'load'), 'primary')
@@ -90,7 +88,6 @@ _affk.tag_subject_of(('Ticket', 'concerns', '*'), {'sort': True})
 
 
 _pvs = uicfg.primaryview_section
-_pvs.tag_object_of(('*', 'interested_in', '*'), 'hidden')
 
 _pvs.tag_subject_of(('Project', 'uses', '*'), 'hidden')
 _pvs.tag_object_of(('*', 'uses', 'Project'), 'hidden')
@@ -122,6 +119,7 @@ _pvs.tag_object_of(('Ticket', 'appeared_in', '*'), 'hidden')
 _pvs.tag_object_of(('*', 'generate_bug', 'Ticket'), 'sideboxes')
 
 _pvs.tag_object_of(('*', 'todo_by', 'CWUser'), 'relations')
+_pvs.tag_subject_of(('Version', 'todo_by', 'CWUser'), 'hidden')
 
 _pvs.tag_attribute(('ExtProject', 'name'), 'hidden')
 
@@ -139,14 +137,10 @@ uicfg.primaryview_display_ctrl.tag_object_of(
 
 _abaa = uicfg.actionbox_appearsin_addmenu
 _abaa.tag_subject_of(('TestInstance', 'generate_bug', 'Ticket'), True)
-_abaa.tag_subject_of(('CWUser', 'todo_by', '*'), False)
-_abaa.tag_subject_of(('*', 'instance_of', '*'), False)
-_abaa.tag_object_of(('*', 'instance_of', '*'), False)
-_abaa.tag_subject_of(('*', 'documented_by', '*'), True)
-_abaa.tag_object_of(('*', 'concerns', 'Project'), True)
-_abaa.tag_object_of(('*', 'test_case_of', 'Project'), True)
-_abaa.tag_object_of(('*', 'done_in', 'Version'), True)
-_abaa.tag_object_of(('*', 'appeared_in', 'Version'), True)
+_abaa.tag_subject_of(('*', 'todo_by', '*'), False)
+_abaa.tag_subject_of(('TestInstance', 'instance_of', 'Card'), False)
+_abaa.tag_object_of(('TestInstance', 'instance_of', 'Card'), False)
+_abaa.tag_object_of(('*', 'for_version', '*'), False)
 
 _abaa.tag_object_of(('TestInstance', 'for_version', 'Version'), False)
 _abaa.tag_object_of(('*', 'test_case_for', 'Ticket'), True)
@@ -154,5 +148,9 @@ _abaa.tag_object_of(('*', 'test_case_for', 'Ticket'), True)
 # add an attachment
 _abaa.tag_subject_of(('Ticket', 'attachment', 'File'), True)
 _abaa.tag_subject_of(('Ticket', 'attachment', 'Image'), False)
-for et in ('Ticket', 'Version', 'TestInstance'):
+for et in ('Ticket', 'Version', 'TestInstance', 'Image'):
     _abaa.tag_object_of((et, 'filed_under', 'Folder'), False)
+
+
+
+
